summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMathias Bauer <mba@openoffice.org>2010-01-13 22:25:07 +0100
committerMathias Bauer <mba@openoffice.org>2010-01-13 22:25:07 +0100
commitf365884ba75eb6385a1ec195498aa957c236ee34 (patch)
treea3abff1bb5e51c733bcbc46bdab38c280bc41515
parentd259b818775aea8ea76e9a3fd6d5a248312590c7 (diff)
#i107450#: move more code out of svx
-rw-r--r--sc/inc/document.hxx8
-rw-r--r--sc/source/core/data/documen2.cxx8
-rw-r--r--sc/source/core/data/documen3.cxx2
-rw-r--r--sc/source/core/data/documen8.cxx6
-rw-r--r--sc/source/core/inc/core_pch.hxx2
-rw-r--r--sc/source/core/tool/ddelink.cxx4
-rw-r--r--sc/source/core/tool/interpr2.cxx6
-rw-r--r--sc/source/filter/excel/xicontent.cxx2
-rw-r--r--sc/source/filter/html/htmlexp.cxx2
-rw-r--r--sc/source/filter/html/htmlpars.cxx2
-rw-r--r--sc/source/filter/rtf/eeimpars.cxx2
-rw-r--r--sc/source/filter/xml/xmlcelli.cxx4
-rw-r--r--sc/source/ui/docshell/arealink.cxx4
-rw-r--r--sc/source/ui/docshell/docfunc.cxx4
-rw-r--r--sc/source/ui/docshell/docsh2.cxx2
-rw-r--r--sc/source/ui/docshell/docsh6.cxx6
-rw-r--r--sc/source/ui/docshell/externalrefmgr.cxx4
-rw-r--r--sc/source/ui/docshell/servobj.cxx2
-rw-r--r--sc/source/ui/docshell/tablink.cxx4
-rw-r--r--sc/source/ui/drawfunc/fuins1.cxx2
-rw-r--r--sc/source/ui/inc/tabvwsh.hxx3
-rw-r--r--sc/source/ui/navipi/content.cxx6
-rw-r--r--sc/source/ui/undo/areasave.cxx10
-rw-r--r--sc/source/ui/undo/undoblk3.cxx16
-rw-r--r--sc/source/ui/unoobj/cellsuno.cxx4
-rw-r--r--sc/source/ui/unoobj/linkuno.cxx14
-rw-r--r--sc/source/ui/view/tabvwsh.cxx9
-rw-r--r--sc/source/ui/view/tabvwshb.cxx2
-rw-r--r--sc/source/ui/view/viewfun2.cxx4
-rw-r--r--sc/source/ui/view/viewutil.cxx1
30 files changed, 78 insertions, 67 deletions
diff --git a/sc/inc/document.hxx b/sc/inc/document.hxx
index 116d25ee901e..f2f863f32b9e 100644
--- a/sc/inc/document.hxx
+++ b/sc/inc/document.hxx
@@ -69,7 +69,9 @@ class SvxBoxInfoItem;
class SvxBoxItem;
class SvxBrushItem;
class SvxForbiddenCharactersTable;
-class SvxLinkManager;
+namespace sfx2 {
+ class LinkManager;
+ }
class SvxSearchItem;
class SvxShadowItem;
class Window;
@@ -260,7 +262,7 @@ private:
ScChartCollection* pChartCollection;
std::auto_ptr< ScTemporaryChartLock > apTemporaryChartLock;
ScPatternAttr* pSelectionAttr; // Attribute eines Blocks
- mutable SvxLinkManager* pLinkManager;
+ mutable sfx2::LinkManager* pLinkManager;
ScFormulaCell* pFormulaTree; // Berechnungsbaum Start
ScFormulaCell* pEOFormulaTree; // Berechnungsbaum Ende, letzte Zelle
ScFormulaCell* pFormulaTrack; // BroadcastTrack Start
@@ -441,7 +443,7 @@ public:
SC_DLLPUBLIC void InitDrawLayer( SfxObjectShell* pDocShell = NULL );
XColorTable* GetColorTable();
- SC_DLLPUBLIC SvxLinkManager* GetLinkManager() const;
+ SC_DLLPUBLIC sfx2::LinkManager* GetLinkManager() const;
SC_DLLPUBLIC const ScDocOptions& GetDocOptions() const;
SC_DLLPUBLIC void SetDocOptions( const ScDocOptions& rOpt );
diff --git a/sc/source/core/data/documen2.cxx b/sc/source/core/data/documen2.cxx
index 73c2b2e9c609..4f5e97a58bce 100644
--- a/sc/source/core/data/documen2.cxx
+++ b/sc/source/core/data/documen2.cxx
@@ -39,7 +39,7 @@
#include <editeng/editeng.hxx>
#include <editeng/forbiddencharacterstable.hxx>
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include <svx/svdpool.hxx>
#include <svx/svdobj.hxx>
#include <sfx2/bindings.hxx>
@@ -228,7 +228,7 @@ ScDocument::ScDocument( ScDocumentMode eMode,
if ( eMode == SCDOCMODE_DOCUMENT )
{
if ( pDocShell )
- pLinkManager = new SvxLinkManager( pDocShell );
+ pLinkManager = new sfx2::LinkManager( pDocShell );
xPoolHelper = new ScPoolHelper( this );
@@ -263,11 +263,11 @@ ScDocument::ScDocument( ScDocumentMode eMode,
aTrackTimer.SetTimeout( 100 );
}
-SvxLinkManager* ScDocument::GetLinkManager() const
+sfx2::LinkManager* ScDocument::GetLinkManager() const
{
if ( bAutoCalc && !pLinkManager && pShell)
{
- pLinkManager = new SvxLinkManager( pShell );
+ pLinkManager = new sfx2::LinkManager( pShell );
}
return pLinkManager;
}
diff --git a/sc/source/core/data/documen3.cxx b/sc/source/core/data/documen3.cxx
index 1ab71df40ca1..7b27d21fe082 100644
--- a/sc/source/core/data/documen3.cxx
+++ b/sc/source/core/data/documen3.cxx
@@ -36,7 +36,7 @@
#include "scitems.hxx"
#include <editeng/langitem.hxx>
#include <svl/srchitem.hxx>
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include <sfx2/bindings.hxx>
#include <sfx2/objsh.hxx>
#include <svl/zforlist.hxx>
diff --git a/sc/source/core/data/documen8.cxx b/sc/source/core/data/documen8.cxx
index 0b7ffd320a87..29529fc89929 100644
--- a/sc/source/core/data/documen8.cxx
+++ b/sc/source/core/data/documen8.cxx
@@ -41,7 +41,7 @@
#include <editeng/editstat.hxx>
#include <editeng/frmdiritem.hxx>
#include <editeng/langitem.hxx>
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include <editeng/scripttypeitem.hxx>
#include <editeng/unolingu.hxx>
#include <sfx2/bindings.hxx>
@@ -1187,7 +1187,7 @@ namespace {
(does not include other links from link manager).
@return The DDE link, if it exists, otherwise 0. */
ScDdeLink* lclGetDdeLink(
- const SvxLinkManager* pLinkManager,
+ const sfx2::LinkManager* pLinkManager,
const String& rAppl, const String& rTopic, const String& rItem, BYTE nMode,
USHORT* pnDdePos = NULL )
{
@@ -1216,7 +1216,7 @@ ScDdeLink* lclGetDdeLink(
/** Returns a pointer to the specified DDE link.
@param nDdePos Index of the DDE link (does not include other links from link manager).
@return The DDE link, if it exists, otherwise 0. */
-ScDdeLink* lclGetDdeLink( const SvxLinkManager* pLinkManager, USHORT nDdePos )
+ScDdeLink* lclGetDdeLink( const sfx2::LinkManager* pLinkManager, USHORT nDdePos )
{
if( pLinkManager )
{
diff --git a/sc/source/core/inc/core_pch.hxx b/sc/source/core/inc/core_pch.hxx
index 25e5a9704151..aa7984a31eb0 100644
--- a/sc/source/core/inc/core_pch.hxx
+++ b/sc/source/core/inc/core_pch.hxx
@@ -230,7 +230,7 @@
#include <vcl/gdimtf.hxx>
#include <svx/svdpage.hxx>
#include <svx/svdlayer.hxx>
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include <ctype.h>
#include <vcl/font.hxx>
#include <editeng/fontitem.hxx>
diff --git a/sc/source/core/tool/ddelink.cxx b/sc/source/core/tool/ddelink.cxx
index 446f892452fc..90705c22a503 100644
--- a/sc/source/core/tool/ddelink.cxx
+++ b/sc/source/core/tool/ddelink.cxx
@@ -35,7 +35,7 @@
// INCLUDE ---------------------------------------------------------------
#include <tools/list.hxx>
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include <sfx2/bindings.hxx>
#include <svl/zforlist.hxx>
@@ -250,7 +250,7 @@ void __EXPORT ScDdeLink::ListenersGone()
ScDocument* pStackDoc = pDoc; // member pDoc can't be used after removing the link
- SvxLinkManager* pLinkMgr = pDoc->GetLinkManager();
+ sfx2::LinkManager* pLinkMgr = pDoc->GetLinkManager();
pLinkMgr->Remove( this); // deletes this
if ( !pLinkMgr->GetLinks().Count() ) // letzten geloescht ?
diff --git a/sc/source/core/tool/interpr2.cxx b/sc/source/core/tool/interpr2.cxx
index cb418476e9d9..36294281b4ca 100644
--- a/sc/source/core/tool/interpr2.cxx
+++ b/sc/source/core/tool/interpr2.cxx
@@ -33,7 +33,7 @@
// INCLUDE ---------------------------------------------------------------
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include <sfx2/dispatch.hxx>
#include <sfx2/objsh.hxx>
#include <svl/stritem.hxx>
@@ -2102,7 +2102,7 @@ void ScInterpreter::ScStyle()
PushIllegalParameter();
}
-ScDdeLink* lcl_GetDdeLink( SvxLinkManager* pLinkMgr,
+ScDdeLink* lcl_GetDdeLink( sfx2::LinkManager* pLinkMgr,
const String& rA, const String& rT, const String& rI, BYTE nM )
{
USHORT nCount = pLinkMgr->GetLinks().Count();
@@ -2145,7 +2145,7 @@ void ScInterpreter::ScDde()
// temporary documents (ScFunctionAccess) have no DocShell
// and no LinkManager -> abort
- SvxLinkManager* pLinkMgr = pDok->GetLinkManager();
+ sfx2::LinkManager* pLinkMgr = pDok->GetLinkManager();
if (!pLinkMgr)
{
PushNoValue();
diff --git a/sc/source/filter/excel/xicontent.cxx b/sc/source/filter/excel/xicontent.cxx
index cb666f1f902c..a9eec56f493b 100644
--- a/sc/source/filter/excel/xicontent.cxx
+++ b/sc/source/filter/excel/xicontent.cxx
@@ -36,7 +36,7 @@
#include <tools/urlobj.hxx>
#include <editeng/editeng.hxx>
#include <editeng/editobj.hxx>
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include <svl/itemset.hxx>
#include "scitems.hxx"
#include <editeng/eeitem.hxx>
diff --git a/sc/source/filter/html/htmlexp.cxx b/sc/source/filter/html/htmlexp.cxx
index 8293014ede39..507e51bf9871 100644
--- a/sc/source/filter/html/htmlexp.cxx
+++ b/sc/source/filter/html/htmlexp.cxx
@@ -53,7 +53,7 @@
#include <editeng/wghtitem.hxx>
#include <svx/xoutbmp.hxx>
#include <editeng/editeng.hxx>
-#include <svx/htmlcfg.hxx>
+#include <svtools/htmlcfg.hxx>
#include <sfx2/docfile.hxx>
#include <sfx2/frmhtmlw.hxx>
#include <sfx2/objsh.hxx>
diff --git a/sc/source/filter/html/htmlpars.cxx b/sc/source/filter/html/htmlpars.cxx
index 67c709baaf27..eeaede243f43 100644
--- a/sc/source/filter/html/htmlpars.cxx
+++ b/sc/source/filter/html/htmlpars.cxx
@@ -37,7 +37,7 @@
#include "scitems.hxx"
#include <editeng/eeitem.hxx>
-#include <svx/htmlcfg.hxx>
+#include <svtools/htmlcfg.hxx>
#include <svx/algitem.hxx>
#include <editeng/colritem.hxx>
#include <editeng/brshitem.hxx>
diff --git a/sc/source/filter/rtf/eeimpars.cxx b/sc/source/filter/rtf/eeimpars.cxx
index 497bc3d57e4d..7cc119c89ec8 100644
--- a/sc/source/filter/rtf/eeimpars.cxx
+++ b/sc/source/filter/rtf/eeimpars.cxx
@@ -47,7 +47,7 @@
#include <svx/svdograf.hxx>
#include <svx/svdpage.hxx>
#include <editeng/scripttypeitem.hxx>
-#include <svx/htmlcfg.hxx>
+#include <svtools/htmlcfg.hxx>
#include <sfx2/sfxhtml.hxx>
#include <svtools/parhtml.hxx>
#include <svl/zforlist.hxx>
diff --git a/sc/source/filter/xml/xmlcelli.cxx b/sc/source/filter/xml/xmlcelli.cxx
index 174acea973ea..615dfc4b20c1 100644
--- a/sc/source/filter/xml/xmlcelli.cxx
+++ b/sc/source/filter/xml/xmlcelli.cxx
@@ -51,7 +51,7 @@
#include "XMLStylesImportHelper.hxx"
#include "arealink.hxx"
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include "convuno.hxx"
#include "XMLConverter.hxx"
#include "scerrors.hxx"
@@ -739,7 +739,7 @@ void ScXMLTableRowCellContext::SetCellRangeSource( const table::CellAddress& rPo
String sSourceStr( pCellRangeSource->sSourceStr );
ScAreaLink* pLink = new ScAreaLink( pDoc->GetDocumentShell(), pCellRangeSource->sURL,
sFilterName, pCellRangeSource->sFilterOptions, sSourceStr, aDestRange, pCellRangeSource->nRefresh );
- SvxLinkManager* pLinkManager = pDoc->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDoc->GetLinkManager();
pLinkManager->InsertFileLink( *pLink, OBJECT_CLIENT_FILE, pCellRangeSource->sURL, &sFilterName, &sSourceStr );
}
}
diff --git a/sc/source/ui/docshell/arealink.cxx b/sc/source/ui/docshell/arealink.cxx
index fc745318b105..a7e1ca1d49bb 100644
--- a/sc/source/ui/docshell/arealink.cxx
+++ b/sc/source/ui/docshell/arealink.cxx
@@ -39,7 +39,7 @@
#include <sfx2/docfile.hxx>
#include <sfx2/fcontnr.hxx>
#include <sfx2/sfxsids.hrc>
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include <svl/stritem.hxx>
#include <vcl/msgbox.hxx>
@@ -130,7 +130,7 @@ void __EXPORT ScAreaLink::DataChanged( const String&,
if (bInCreate)
return;
- SvxLinkManager* pLinkManager=pImpl->m_pDocSh->GetDocument()->GetLinkManager();
+ sfx2::LinkManager* pLinkManager=pImpl->m_pDocSh->GetDocument()->GetLinkManager();
if (pLinkManager!=NULL)
{
String aFile;
diff --git a/sc/source/ui/docshell/docfunc.cxx b/sc/source/ui/docshell/docfunc.cxx
index 1ab8abcc9183..09e13286e17a 100644
--- a/sc/source/ui/docshell/docfunc.cxx
+++ b/sc/source/ui/docshell/docfunc.cxx
@@ -40,7 +40,7 @@
#include <sfx2/app.hxx>
#include <editeng/editobj.hxx>
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include <svx/svdundo.hxx>
#include <sfx2/bindings.hxx>
#include <sfx2/printer.hxx>
@@ -4551,7 +4551,7 @@ BOOL ScDocFunc::InsertAreaLink( const String& rFile, const String& rFilter,
ScDocument* pDoc = rDocShell.GetDocument();
BOOL bUndo (pDoc->IsUndoEnabled());
- SvxLinkManager* pLinkManager = pDoc->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDoc->GetLinkManager();
// #i52120# if other area links exist at the same start position,
// remove them first (file format specifies only one link definition
diff --git a/sc/source/ui/docshell/docsh2.cxx b/sc/source/ui/docshell/docsh2.cxx
index 9e0084c0b385..9f5af0f6dd19 100644
--- a/sc/source/ui/docshell/docsh2.cxx
+++ b/sc/source/ui/docshell/docsh2.cxx
@@ -48,7 +48,7 @@
#include <svx/svdobj.hxx>
#include <svx/svdoole2.hxx>
#include <vcl/svapp.hxx>
-#include <svx/asiancfg.hxx>
+#include <svl/asiancfg.hxx>
#include <editeng/forbiddencharacterstable.hxx>
#include <editeng/unolingu.hxx>
#include <rtl/logfile.hxx>
diff --git a/sc/source/ui/docshell/docsh6.cxx b/sc/source/ui/docshell/docsh6.cxx
index e3f1f6904af4..5a81e181d168 100644
--- a/sc/source/ui/docshell/docsh6.cxx
+++ b/sc/source/ui/docshell/docsh6.cxx
@@ -40,7 +40,7 @@
#include <svx/pageitem.hxx>
#include <vcl/virdev.hxx>
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#endif
// INCLUDE ---------------------------------------------------------------
@@ -367,7 +367,7 @@ BOOL __EXPORT ScDocShell::Insert( SfxObjectShell &rSource,
void ScDocShell::UpdateLinks()
{
- SvxLinkManager* pLinkManager = aDocument.GetLinkManager();
+ sfx2::LinkManager* pLinkManager = aDocument.GetLinkManager();
ScStrCollection aNames;
// nicht mehr benutzte Links raus
@@ -438,7 +438,7 @@ void ScDocShell::UpdateLinks()
BOOL ScDocShell::ReloadTabLinks()
{
- SvxLinkManager* pLinkManager = aDocument.GetLinkManager();
+ sfx2::LinkManager* pLinkManager = aDocument.GetLinkManager();
BOOL bAny = FALSE;
USHORT nCount = pLinkManager->GetLinks().Count();
diff --git a/sc/source/ui/docshell/externalrefmgr.cxx b/sc/source/ui/docshell/externalrefmgr.cxx
index e18ef20d96b9..3d2251dde51f 100644
--- a/sc/source/ui/docshell/externalrefmgr.cxx
+++ b/sc/source/ui/docshell/externalrefmgr.cxx
@@ -61,7 +61,7 @@
#include "svl/stritem.hxx"
#include "svl/urihelper.hxx"
#include "svl/zformat.hxx"
-#include "svx/linkmgr.hxx"
+#include "sfx2/linkmgr.hxx"
#include "tools/urlobj.hxx"
#include "unotools/ucbhelper.hxx"
@@ -1994,7 +1994,7 @@ void ScExternalRefManager::maybeLinkExternalFile(sal_uInt16 nFileId)
String aFilter, aOptions;
ScDocumentLoader::GetFilterName(*pFileName, aFilter, aOptions, true, false);
- SvxLinkManager* pLinkMgr = mpDoc->GetLinkManager();
+ sfx2::LinkManager* pLinkMgr = mpDoc->GetLinkManager();
ScExternalRefLink* pLink = new ScExternalRefLink(mpDoc, nFileId, aFilter);
DBG_ASSERT(pFileName, "ScExternalRefManager::insertExternalFileLink: file name pointer is NULL");
pLinkMgr->InsertFileLink(*pLink, OBJECT_CLIENT_FILE, *pFileName, &aFilter);
diff --git a/sc/source/ui/docshell/servobj.cxx b/sc/source/ui/docshell/servobj.cxx
index aeb4b6604e67..93e23948a13b 100644
--- a/sc/source/ui/docshell/servobj.cxx
+++ b/sc/source/ui/docshell/servobj.cxx
@@ -36,7 +36,7 @@
#include <sot/formats.hxx>
#include <sfx2/app.hxx>
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include "servobj.hxx"
#include "docsh.hxx"
#include "impex.hxx"
diff --git a/sc/source/ui/docshell/tablink.cxx b/sc/source/ui/docshell/tablink.cxx
index c86c7591cd36..dcfb6bf1dc62 100644
--- a/sc/source/ui/docshell/tablink.cxx
+++ b/sc/source/ui/docshell/tablink.cxx
@@ -47,7 +47,7 @@
#include <sfx2/docfile.hxx>
#include <sfx2/docfilt.hxx>
#include <sfx2/fcontnr.hxx>
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include <tools/urlobj.hxx>
#include <unotools/transliterationwrapper.hxx>
@@ -146,7 +146,7 @@ void __EXPORT ScTableLink::Edit( Window* pParent, const Link& rEndEditHdl )
void __EXPORT ScTableLink::DataChanged( const String&,
const ::com::sun::star::uno::Any& )
{
- SvxLinkManager* pLinkManager=pImpl->m_pDocSh->GetDocument()->GetLinkManager();
+ sfx2::LinkManager* pLinkManager=pImpl->m_pDocSh->GetDocument()->GetLinkManager();
if (pLinkManager!=NULL)
{
String aFile;
diff --git a/sc/source/ui/drawfunc/fuins1.cxx b/sc/source/ui/drawfunc/fuins1.cxx
index a8484c2d8b88..3ba147efa092 100644
--- a/sc/source/ui/drawfunc/fuins1.cxx
+++ b/sc/source/ui/drawfunc/fuins1.cxx
@@ -31,7 +31,7 @@
// MARKER(update_precomp.py): autogen include statement, do not remove
#include "precompiled_sc.hxx"
-#include <svx/opengrf.hxx>
+#include <sfx2/opengrf.hxx>
#include <svx/svdograf.hxx>
#include <svx/svdomedia.hxx>
#include <svx/svdpage.hxx>
diff --git a/sc/source/ui/inc/tabvwsh.hxx b/sc/source/ui/inc/tabvwsh.hxx
index d61fa8a17420..da358ed6e321 100644
--- a/sc/source/ui/inc/tabvwsh.hxx
+++ b/sc/source/ui/inc/tabvwsh.hxx
@@ -31,6 +31,7 @@
#ifndef SC_TABVWSH_HXX
#define SC_TABVWSH_HXX
+#include <svtools/htmlcfg.hxx>
#include <sfx2/viewsh.hxx>
#include <sfx2/viewfac.hxx>
#include <editeng/svxenum.hxx>
@@ -106,6 +107,7 @@ private:
static USHORT nInsCellsCtrlState;
static USHORT nInsObjCtrlState;
+ SvxHtmlOptions aHTMLOpt;
ObjectSelectionType eCurOST;
USHORT nDrawSfxId;
USHORT nCtrlSfxId;
@@ -198,6 +200,7 @@ private:
DECL_LINK( SimpleRefAborted, String* );
DECL_LINK( SimpleRefChange, String* );
DECL_LINK( FormControlActivated, FmFormShell* );
+ DECL_LINK( HtmlOptionsHdl, void * );
protected:
virtual void Activate(BOOL bMDI);
diff --git a/sc/source/ui/navipi/content.cxx b/sc/source/ui/navipi/content.cxx
index 8198e6adb0f4..2425faa0cb06 100644
--- a/sc/source/ui/navipi/content.cxx
+++ b/sc/source/ui/navipi/content.cxx
@@ -39,7 +39,7 @@
#include <svx/svdpagv.hxx>
#include <svx/svdview.hxx>
#include <svx/svdxcgv.hxx>
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include <sfx2/docfile.hxx>
#include <sfx2/viewfrm.hxx>
#include <vcl/help.hxx>
@@ -830,7 +830,7 @@ void ScContentTree::GetLinkNames()
if (!pDoc)
return;
- SvxLinkManager* pLinkManager = pDoc->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDoc->GetLinkManager();
DBG_ASSERT(pLinkManager, "kein LinkManager am Dokument?");
const ::sfx2::SvBaseLinks& rLinks = pLinkManager->GetLinks();
USHORT nCount = rLinks.Count();
@@ -851,7 +851,7 @@ const ScAreaLink* ScContentTree::GetLink( ULONG nIndex )
return NULL;
ULONG nFound = 0;
- SvxLinkManager* pLinkManager = pDoc->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDoc->GetLinkManager();
DBG_ASSERT(pLinkManager, "kein LinkManager am Dokument?");
const ::sfx2::SvBaseLinks& rLinks = pLinkManager->GetLinks();
USHORT nCount = rLinks.Count();
diff --git a/sc/source/ui/undo/areasave.cxx b/sc/source/ui/undo/areasave.cxx
index a1ca8b9dabeb..d390c4448106 100644
--- a/sc/source/ui/undo/areasave.cxx
+++ b/sc/source/ui/undo/areasave.cxx
@@ -37,7 +37,7 @@
// INCLUDE ---------------------------------------------------------------
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include <tools/debug.hxx>
#include "areasave.hxx"
@@ -100,7 +100,7 @@ void ScAreaLinkSaver::InsertNewLink( ScDocument* pDoc ) const
{
// (see ScUndoRemoveAreaLink::Undo)
- SvxLinkManager* pLinkManager = pDoc->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDoc->GetLinkManager();
SfxObjectShell* pObjSh = pDoc->GetDocumentShell();
if ( pLinkManager && pObjSh )
@@ -140,7 +140,7 @@ BOOL ScAreaLinkSaveCollection::IsEqual( const ScDocument* pDoc ) const
// IsEqual can be checked in sequence.
// Neither ref-update nor removing links will change the order.
- SvxLinkManager* pLinkManager = const_cast<ScDocument*>(pDoc)->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = const_cast<ScDocument*>(pDoc)->GetLinkManager();
if (pLinkManager)
{
USHORT nPos = 0;
@@ -186,7 +186,7 @@ void ScAreaLinkSaveCollection::Restore( ScDocument* pDoc ) const
// Entries from the save collection must be searched via source data, as the order
// of links changes if deleted entries are re-added to the link manager (always at the end).
- SvxLinkManager* pLinkManager = pDoc->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDoc->GetLinkManager();
if (pLinkManager)
{
const ::sfx2::SvBaseLinks& rLinks = pLinkManager->GetLinks();
@@ -208,7 +208,7 @@ ScAreaLinkSaveCollection* ScAreaLinkSaveCollection::CreateFromDoc( const ScDocum
{
ScAreaLinkSaveCollection* pColl = NULL;
- SvxLinkManager* pLinkManager = const_cast<ScDocument*>(pDoc)->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = const_cast<ScDocument*>(pDoc)->GetLinkManager();
if (pLinkManager)
{
const ::sfx2::SvBaseLinks& rLinks = pLinkManager->GetLinks();
diff --git a/sc/source/ui/undo/undoblk3.cxx b/sc/source/ui/undo/undoblk3.cxx
index a9cdd12ceac9..4e3a5d9d9f08 100644
--- a/sc/source/ui/undo/undoblk3.cxx
+++ b/sc/source/ui/undo/undoblk3.cxx
@@ -36,7 +36,7 @@
#include "scitems.hxx"
#include <editeng/boxitem.hxx>
#include <svl/srchitem.hxx>
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include <sfx2/bindings.hxx>
#include <vcl/virdev.hxx>
#include <sfx2/app.hxx>
@@ -1755,7 +1755,7 @@ BOOL __EXPORT ScUndoRefreshLink::CanRepeat(SfxRepeatTarget& /* rTarget */) const
//----------------------------------------------------------------------------
-ScAreaLink* lcl_FindAreaLink( SvxLinkManager* pLinkManager, const String& rDoc,
+ScAreaLink* lcl_FindAreaLink( sfx2::LinkManager* pLinkManager, const String& rDoc,
const String& rFlt, const String& rOpt,
const String& rSrc, const ScRange& rDest )
{
@@ -1819,7 +1819,7 @@ String __EXPORT ScUndoInsertAreaLink::GetComment() const
void __EXPORT ScUndoInsertAreaLink::Undo()
{
ScDocument* pDoc = pDocShell->GetDocument();
- SvxLinkManager* pLinkManager = pDoc->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDoc->GetLinkManager();
ScAreaLink* pLink = lcl_FindAreaLink( pLinkManager, aDocName, aFltName, aOptions,
aAreaName, aRange );
@@ -1835,7 +1835,7 @@ void __EXPORT ScUndoInsertAreaLink::Undo()
void __EXPORT ScUndoInsertAreaLink::Redo()
{
ScDocument* pDoc = pDocShell->GetDocument();
- SvxLinkManager* pLinkManager = pDoc->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDoc->GetLinkManager();
ScAreaLink* pLink = new ScAreaLink( pDocShell, aDocName, aFltName, aOptions,
aAreaName, aRange.aStart, nRefreshDelay );
@@ -1909,7 +1909,7 @@ String __EXPORT ScUndoRemoveAreaLink::GetComment() const
void __EXPORT ScUndoRemoveAreaLink::Undo()
{
ScDocument* pDoc = pDocShell->GetDocument();
- SvxLinkManager* pLinkManager = pDoc->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDoc->GetLinkManager();
ScAreaLink* pLink = new ScAreaLink( pDocShell, aDocName, aFltName, aOptions,
aAreaName, aRange.aStart, nRefreshDelay );
@@ -1928,7 +1928,7 @@ void __EXPORT ScUndoRemoveAreaLink::Undo()
void __EXPORT ScUndoRemoveAreaLink::Redo()
{
ScDocument* pDoc = pDocShell->GetDocument();
- SvxLinkManager* pLinkManager = pDoc->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDoc->GetLinkManager();
ScAreaLink* pLink = lcl_FindAreaLink( pLinkManager, aDocName, aFltName, aOptions,
aAreaName, aRange );
@@ -2074,7 +2074,7 @@ void ScUndoUpdateAreaLink::DoChange( const BOOL bUndo ) const
void __EXPORT ScUndoUpdateAreaLink::Undo()
{
ScDocument* pDoc = pDocShell->GetDocument();
- SvxLinkManager* pLinkManager = pDoc->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDoc->GetLinkManager();
ScAreaLink* pLink = lcl_FindAreaLink( pLinkManager, aNewDoc, aNewFlt, aNewOpt,
aNewArea, aNewRange );
if (pLink)
@@ -2093,7 +2093,7 @@ void __EXPORT ScUndoUpdateAreaLink::Undo()
void __EXPORT ScUndoUpdateAreaLink::Redo()
{
ScDocument* pDoc = pDocShell->GetDocument();
- SvxLinkManager* pLinkManager = pDoc->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDoc->GetLinkManager();
ScAreaLink* pLink = lcl_FindAreaLink( pLinkManager, aOldDoc, aOldFlt, aOldOpt,
aOldArea, aOldRange );
if (pLink)
diff --git a/sc/source/ui/unoobj/cellsuno.cxx b/sc/source/ui/unoobj/cellsuno.cxx
index a22bfb6cb114..585dab7881f6 100644
--- a/sc/source/ui/unoobj/cellsuno.cxx
+++ b/sc/source/ui/unoobj/cellsuno.cxx
@@ -43,7 +43,7 @@
#include <editeng/flditem.hxx>
#include <svx/fmdpage.hxx>
#include <editeng/langitem.hxx>
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include <svl/srchitem.hxx>
#include <svx/unomid.hxx>
#include <editeng/unoprnms.hxx>
@@ -7681,7 +7681,7 @@ void SAL_CALL ScTableSheetObj::link( const rtl::OUString& aUrl, const rtl::OUStr
// Update immer, auch wenn der Link schon da war
//! Update nur fuer die betroffene Tabelle???
- SvxLinkManager* pLinkManager = pDoc->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDoc->GetLinkManager();
USHORT nCount = pLinkManager->GetLinks().Count();
for ( USHORT i=0; i<nCount; i++ )
{
diff --git a/sc/source/ui/view/tabvwsh.cxx b/sc/source/ui/view/tabvwsh.cxx
index 03c9b6bd395f..c3d20f967779 100644
--- a/sc/source/ui/view/tabvwsh.cxx
+++ b/sc/source/ui/view/tabvwsh.cxx
@@ -42,6 +42,8 @@
#include <svl/srchitem.hxx>
#include <sfx2/templdlg.hxx>
#include <sfx2/objface.hxx>
+#include <sfx2/viewfrm.hxx>
+#include <sfx2/bindings.hxx>
#include <sfx2/app.hxx>
#include <avmedia/mediaplayer.hxx>
@@ -109,4 +111,9 @@ SFX_IMPL_VIEWFACTORY( ScTabViewShell, ScResId(STR_NONAME) )
//------------------------------------------------------------------
-
+IMPL_LINK( ScTabViewShell, HtmlOptionsHdl, void*, EMPTYARG )
+{
+ // Invalidierung, falls blinkender Text erlaubt/verboten wurde
+ GetViewFrame()->GetBindings().Invalidate(SID_DRAW_TEXT_MARQUEE);
+ return 0;
+}
diff --git a/sc/source/ui/view/tabvwshb.cxx b/sc/source/ui/view/tabvwshb.cxx
index 72ffe6d5ab10..e7ada810799f 100644
--- a/sc/source/ui/view/tabvwshb.cxx
+++ b/sc/source/ui/view/tabvwshb.cxx
@@ -57,7 +57,7 @@
#include <svx/svdoole2.hxx>
#include <svx/svdouno.hxx>
#include <svx/svdview.hxx>
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include <svx/fontworkbar.hxx>
#include <sfx2/bindings.hxx>
#include <sfx2/dispatch.hxx>
diff --git a/sc/source/ui/view/viewfun2.cxx b/sc/source/ui/view/viewfun2.cxx
index 79d9e780d7c1..dbe9b840a345 100644
--- a/sc/source/ui/view/viewfun2.cxx
+++ b/sc/source/ui/view/viewfun2.cxx
@@ -44,7 +44,7 @@
#include <editeng/fontitem.hxx>
#include <editeng/scripttypeitem.hxx>
#include <svl/srchitem.hxx>
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include <sfx2/dispatch.hxx>
#include <sfx2/docfilt.hxx>
#include <sfx2/docfile.hxx>
@@ -2408,7 +2408,7 @@ void ScViewFunc::ImportTables( ScDocShell* pSrcShell,
if (bLink)
{
- SvxLinkManager* pLinkManager = pDoc->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDoc->GetLinkManager();
SfxMedium* pMed = pSrcShell->GetMedium();
String aFileName = pMed->GetName();
diff --git a/sc/source/ui/view/viewutil.cxx b/sc/source/ui/view/viewutil.cxx
index b7f58d453f9f..e327ff32bbc8 100644
--- a/sc/source/ui/view/viewutil.cxx
+++ b/sc/source/ui/view/viewutil.cxx
@@ -39,7 +39,6 @@
#include <sfx2/bindings.hxx>
#include <sfx2/viewsh.hxx>
#include <sfx2/dispatch.hxx>
-#include <svx/charmap.hxx>
#include <editeng/fontitem.hxx>
#include <editeng/langitem.hxx>
#include <editeng/scripttypeitem.hxx>
diff --git a/sc/source/ui/unoobj/linkuno.cxx b/sc/source/ui/unoobj/linkuno.cxx
index ddb5dc3b0496..7aadfa44388f 100644
--- a/sc/source/ui/unoobj/linkuno.cxx
+++ b/sc/source/ui/unoobj/linkuno.cxx
@@ -34,7 +34,7 @@
#include <svl/smplhint.hxx>
-#include <svx/linkmgr.hxx>
+#include <sfx2/linkmgr.hxx>
#include "linkuno.hxx"
#include "miscuno.hxx"
@@ -131,7 +131,7 @@ ScTableLink* ScSheetLinkObj::GetLink_Impl() const
{
if (pDocShell)
{
- SvxLinkManager* pLinkManager = pDocShell->GetDocument()->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDocShell->GetDocument()->GetLinkManager();
USHORT nCount = pLinkManager->GetLinks().Count();
for (USHORT i=0; i<nCount; i++)
{
@@ -304,7 +304,7 @@ void ScSheetLinkObj::setFileName(const rtl::OUString& rNewName)
ScTableLink* pLink = GetLink_Impl();
if (pLink)
{
// pLink->Refresh mit neuem Dateinamen bringt SvxLinkManager durcheinander
// darum per Hand die Tabellen umsetzen und Link per UpdateLinks neu erzeugen
String aNewStr(ScGlobal::GetAbsDocName( String(rNewName), pDocShell ));
@@ -605,7 +605,7 @@ ScAreaLink* lcl_GetAreaLink( ScDocShell* pDocShell, USHORT nPos )
{
if (pDocShell)
{
- SvxLinkManager* pLinkManager = pDocShell->GetDocument()->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDocShell->GetDocument()->GetLinkManager();
USHORT nTotalCount = pLinkManager->GetLinks().Count();
USHORT nAreaCount = 0;
for (USHORT i=0; i<nTotalCount; i++)
@@ -678,7 +678,7 @@ void ScAreaLinkObj::Modify_Impl( const rtl::OUString* pNewFile, const rtl::OUStr
//! Undo fuer Loeschen
//! Undo zusammenfassen
- SvxLinkManager* pLinkManager = pDocShell->GetDocument()->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDocShell->GetDocument()->GetLinkManager();
pLinkManager->Remove( pLink );
pLink = NULL; // bei Remove geloescht
@@ -1004,7 +1004,7 @@ void SAL_CALL ScAreaLinksObj::removeByIndex( sal_Int32 nIndex ) throw(uno::Runti
{
//! SetAddUndo oder so
- SvxLinkManager* pLinkManager = pDocShell->GetDocument()->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDocShell->GetDocument()->GetLinkManager();
pLinkManager->Remove( pLink );
}
}
@@ -1026,7 +1026,7 @@ sal_Int32 SAL_CALL ScAreaLinksObj::getCount() throw(uno::RuntimeException)
INT32 nAreaCount = 0;
if (pDocShell)
{
- SvxLinkManager* pLinkManager = pDocShell->GetDocument()->GetLinkManager();
+ sfx2::LinkManager* pLinkManager = pDocShell->GetDocument()->GetLinkManager();
USHORT nTotalCount = pLinkManager->GetLinks().Count();
for (USHORT i=0; i<nTotalCount; i++)
{
@@ -304,7 +304,7 @@ void ScSheetLinkObj::setFileName(const rtl::OUString& rNewName)
if (pLink)
{
- // pLink->Refresh mit neuem Dateinamen bringt SvxLinkManager durcheinander
+ // pLink->Refresh mit neuem Dateinamen bringt sfx2::LinkManager durcheinander
// darum per Hand die Tabellen umsetzen und Link per UpdateLinks neu erzeugen
String aNewStr(ScGlobal::GetAbsDocName( String(rNewName), pDocShell ));